@@ -28,8 +28,19 @@ pub fn get_display_inner(text: &str, base_dir: Option<char>, debug: bool) -> PyR
     Ok(display)
 }
 
+#[pyfunction]
+pub fn get_base_level_inner(text: &str) -> PyResult<u8> {
+    let bidi_info = BidiInfo::new(text, None);
+    if bidi_info.paragraphs.is_empty() {
+        return Err(PyValueError::new_err("Text contains no paragraphs"));
+    }
+
+    Ok(bidi_info.paragraphs[0].level.number())
+}
+
 #[pymodule]
 fn bidi(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(get_display_inner, m)?)?;
+    m.add_function(wrap_pyfunction!(get_base_level_inner, m)?)?;
     Ok(())
 }
